#[repr(u8)]pub enum BatChargeFault {
Unspecified = 0,
Ambienttoohot = 1,
Ambienttoocold = 2,
Batterytoohot = 3,
Batterytoocold = 4,
Batteryabsent = 5,
Batteryovervoltage = 6,
Batteryundervoltage = 7,
Chargerovervoltage = 8,
Chargerundervoltage = 9,
Safetytimeout = 10,
}Variants
Unspecified = 0
The Node detects an unspecified fault on this battery source.
Ambienttoohot = 1
The Node detects the ambient temperature is above the nominal range for this battery source.
Ambienttoocold = 2
The Node detects the ambient temperature is below the nominal range for this battery source.
Batterytoohot = 3
The Node detects the temperature of this battery source is above the nominal range.
Batterytoocold = 4
The Node detects the temperature of this battery source is below the nominal range.
Batteryabsent = 5
The Node detects this battery source is not present.
Batteryovervoltage = 6
The Node detects this battery source is over voltage.
Batteryundervoltage = 7
The Node detects this battery source is under voltage.
Chargerovervoltage = 8
The Node detects the charger for this battery source is over voltage.
Chargerundervoltage = 9
The Node detects the charger for this battery source is under voltage.
Safetytimeout = 10
The Node detects a charging safety timeout for this battery source.
Implementations