#[repr(u8)]pub enum BatFault {
Unspecified = 0,
Overtemp = 1,
Undertemp = 2,
}Variants
Unspecified = 0
The Node detects an unspecified fault on this battery power source.
Overtemp = 1
The Node detects the temperature of this battery power source is above ideal operating conditions.
Undertemp = 2
The Node detects the temperature of this battery power source is below ideal operating conditions.
Implementations