#[repr(u8)]pub enum PowerSourceStatus {
Unspecified = 0,
Active = 1,
Standby = 2,
Unavailable = 3,
}Variants
Unspecified = 0
Indicate the source status is not specified
Active = 1
Indicate the source is available and currently supplying power
Standby = 2
Indicate the source is available, but is not currently supplying power
Indicate the source is not currently available to supply power
Implementations