#[repr(u8)]pub enum WiredFault {
Unspecified = 0,
Overvoltage = 1,
Undervoltage = 2,
}Variants
Unspecified = 0
The Node detects an unspecified fault on this wired power source.
Overvoltage = 1
The Node detects the supplied voltage is above maximum supported value for this wired power source.
Undervoltage = 2
The Node detects the supplied voltage is below maximum supported value for this wired power source.
Implementations