#[repr(u8)]pub enum BatReplaceability {
Unspecified = 0,
Notreplaceable = 1,
Userreplaceable = 2,
Factoryreplaceable = 3,
}Variants
Unspecified = 0
The replaceability is unspecified or unknown.
Notreplaceable = 1
The battery is not replaceable.
Userreplaceable = 2
The battery is replaceable by the user or customer.
Factoryreplaceable = 3
The battery is replaceable by an authorized factory technician.
Implementations